@@ -86,68 +86,6 @@ INSERT INTO "usage" VALUES(
     'EPSG','1024'  -- unknown
 );
 
--- Iceland
-
-INSERT INTO "grid_transformation" VALUES(
-    'PROJ','EPSG_5323_TO_EPSG_8089','ISN2004 to ISH2004 height',
-    NULL,
-    'EPSG','9665','Geographic3D to GravityRelatedHeight (gtx)',
-    'EPSG','5323', -- source CRS (ISN2004 geographic 3D)
-    'EPSG','8089', -- target CRS (ISH2004 height)
-    NULL,
-    'EPSG','8666','Geoid (height correction) model file','Icegeoid_ISN2004.gtx',
-    NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
-
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'EPSG_5323_TO_EPSG_8089_USAGE',
-    'grid_transformation',
-    'PROJ',
-    'EPSG_5323_TO_EPSG_8089',
-    'EPSG','1120', -- area of use: Iceland - onshore and offshore
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "grid_transformation" VALUES(
-    'PROJ','EPSG_4945_TO_EPSG_8089','ISN93 to ISH2004 height',
-    NULL,
-    'EPSG','9665','Geographic3D to GravityRelatedHeight (gtx)',
-    'EPSG','4945', -- source CRS (ISN93 geographic 3D)
-    'EPSG','8089', -- target CRS (ISH2004 height)
-    NULL,
-    'EPSG','8666','Geoid (height correction) model file','Icegeoid_ISN93.gtx',
-    NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
-
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'EPSG_4945_TO_EPSG_8089_USAGE',
-    'grid_transformation',
-    'PROJ',
-    'EPSG_4945_TO_EPSG_8089',
-    'EPSG','1120', -- area of use: Iceland - onshore and offshore
-    'EPSG','1024'  -- unknown
-);
-
-INSERT INTO "grid_transformation" VALUES(
-    'PROJ','EPSG_8085_TO_EPSG_8089','ISN2016 to ISH2004 height',
-    NULL,
-    'EPSG','9665','Geographic3D to GravityRelatedHeight (gtx)',
-    'EPSG','8085', -- source CRS (ISN2016 geographic 3D)
-    'EPSG','8089', -- target CRS (ISH2004 height)
-    NULL,
-    'EPSG','8666','Geoid (height correction) model file','Icegeoid_ISN2016.gtx',
-    NULL,NULL,NULL,NULL,NULL,NULL,NULL,0);
-
-INSERT INTO "usage" VALUES(
-    'PROJ',
-    'EPSG_8085_TO_EPSG_8089_USAGE',
-    'grid_transformation',
-    'PROJ',
-    'EPSG_8085_TO_EPSG_8089',
-    'EPSG','1120', -- area of use: Iceland - onshore and offshore
-    'EPSG','1024'  -- unknown
-);
-
 -- Japan
 
 INSERT INTO "grid_transformation" VALUES(
