@@ -93,6 +93,12 @@ using CoordinateOperationPtr = std::shared_ptr<CoordinateOperation>;
 /** Non-null shared pointer of CoordinateOperation */
 using CoordinateOperationNNPtr = util::nn<CoordinateOperationPtr>;
 
+class Transformation;
+/** Shared pointer of Transformation */
+using TransformationPtr = std::shared_ptr<Transformation>;
+/** Non-null shared pointer of Transformation */
+using TransformationNNPtr = util::nn<TransformationPtr>;
+
 /** \brief Abstract class for a mathematical operation on coordinates.
  *
  * A mathematical operation:
@@ -171,12 +177,15 @@ class PROJ_GCC_DLL CoordinateOperation : public common::ObjectUsage,
     PROJ_FRIEND(io::AuthorityFactory);
     PROJ_FRIEND(CoordinateOperationFactory);
     PROJ_FRIEND(ConcatenatedOperation);
+    PROJ_FRIEND(io::WKTParser);
     PROJ_INTERNAL void
     setWeakSourceTargetCRS(std::weak_ptr<crs::CRS> sourceCRSIn,
                            std::weak_ptr<crs::CRS> targetCRSIn);
     PROJ_INTERNAL void setCRSs(const crs::CRSNNPtr &sourceCRSIn,
                                const crs::CRSNNPtr &targetCRSIn,
                                const crs::CRSPtr &interpolationCRSIn);
+    PROJ_INTERNAL void
+    setInterpolationCRS(const crs::CRSPtr &interpolationCRSIn);
     PROJ_INTERNAL void setCRSs(const CoordinateOperation *in,
                                bool inverseSourceTarget);
     PROJ_INTERNAL
@@ -583,18 +592,18 @@ class PROJ_GCC_DLL SingleOperation : virtual public CoordinateOperation {
     PROJ_DLL const OperationMethodNNPtr &method() PROJ_PURE_DECL;
 
     PROJ_DLL const ParameterValuePtr &
-    parameterValue(const std::string &paramName, int epsg_code = 0) const
-        noexcept;
+    parameterValue(const std::string &paramName,
+                   int epsg_code = 0) const noexcept;
 
-    PROJ_DLL const ParameterValuePtr &parameterValue(int epsg_code) const
-        noexcept;
+    PROJ_DLL const ParameterValuePtr &
+    parameterValue(int epsg_code) const noexcept;
 
     PROJ_DLL const common::Measure &
-    parameterValueMeasure(const std::string &paramName, int epsg_code = 0) const
-        noexcept;
+    parameterValueMeasure(const std::string &paramName,
+                          int epsg_code = 0) const noexcept;
 
-    PROJ_DLL const common::Measure &parameterValueMeasure(int epsg_code) const
-        noexcept;
+    PROJ_DLL const common::Measure &
+    parameterValueMeasure(int epsg_code) const noexcept;
 
     PROJ_DLL static SingleOperationNNPtr createPROJBased(
         const util::PropertyMap &properties, const std::string &PROJString,
@@ -608,27 +617,32 @@ class PROJ_GCC_DLL SingleOperation : virtual public CoordinateOperation {
 
     PROJ_DLL std::list<std::string> validateParameters() const;
 
+    PROJ_DLL TransformationNNPtr substitutePROJAlternativeGridNames(
+        io::DatabaseContextNNPtr databaseContext) const;
+
     PROJ_PRIVATE :
         //! @cond Doxygen_Suppress
 
         PROJ_DLL double
-        parameterValueNumeric(int epsg_code,
-                              const common::UnitOfMeasure &targetUnit) const
-        noexcept;
+        parameterValueNumeric(
+            int epsg_code,
+            const common::UnitOfMeasure &targetUnit) const noexcept;
+
+    PROJ_INTERNAL double parameterValueNumeric(
+        const char *param_name,
+        const common::UnitOfMeasure &targetUnit) const noexcept;
 
     PROJ_INTERNAL double
-    parameterValueNumeric(const char *param_name,
-                          const common::UnitOfMeasure &targetUnit) const
-        noexcept;
-
-    PROJ_INTERNAL double parameterValueNumericAsSI(int epsg_code) const
-        noexcept;
+    parameterValueNumericAsSI(int epsg_code) const noexcept;
 
     PROJ_INTERNAL bool _isEquivalentTo(
         const util::IComparable *other,
         util::IComparable::Criterion criterion =
             util::IComparable::Criterion::STRICT,
         const io::DatabaseContextPtr &dbContext = nullptr) const override;
+
+    PROJ_INTERNAL bool isLongitudeRotation() const;
+
     //! @endcond
 
   protected:
@@ -741,7 +755,7 @@ projection grid at the natural origin.
 
 EPSG:8807
 
-\subsection latitude_projection_centre Latitute of projection centre
+\subsection latitude_projection_centre Latitude of projection centre
 
 For an oblique projection, this is the latitude of the point at which the
 azimuth of the central line is defined.
@@ -1341,10 +1355,19 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
         const common::Angle &southPoleLongInUnrotatedCRS,
         const common::Angle &axisRotation);
 
+    PROJ_DLL static ConversionNNPtr createPoleRotationNetCDFCFConvention(
+        const util::PropertyMap &properties,
+        const common::Angle &gridNorthPoleLatitude,
+        const common::Angle &gridNorthPoleLongitude,
+        const common::Angle &northPoleGridLongitude);
+
     PROJ_DLL static ConversionNNPtr
     createChangeVerticalUnit(const util::PropertyMap &properties,
                              const common::Scale &factor);
 
+    PROJ_DLL static ConversionNNPtr
+    createChangeVerticalUnit(const util::PropertyMap &properties);
+
     PROJ_DLL static ConversionNNPtr
     createHeightDepthReversal(const util::PropertyMap &properties);
 
@@ -1353,6 +1376,23 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
     PROJ_DLL static ConversionNNPtr
     createGeographicGeocentric(const util::PropertyMap &properties);
 
+    PROJ_DLL static ConversionNNPtr
+    createGeographic2DOffsets(const util::PropertyMap &properties,
+                              const common::Angle &offsetLat,
+                              const common::Angle &offsetLon);
+
+    PROJ_DLL static ConversionNNPtr createGeographic3DOffsets(
+        const util::PropertyMap &properties, const common::Angle &offsetLat,
+        const common::Angle &offsetLon, const common::Length &offsetHeight);
+
+    PROJ_DLL static ConversionNNPtr createGeographic2DWithHeightOffsets(
+        const util::PropertyMap &properties, const common::Angle &offsetLat,
+        const common::Angle &offsetLon, const common::Length &offsetHeight);
+
+    PROJ_DLL static ConversionNNPtr
+    createVerticalOffset(const util::PropertyMap &properties,
+                         const common::Length &offsetHeight);
+
     PROJ_DLL ConversionPtr convertToOtherMethod(int targetEPSGCode) const;
 
     PROJ_PRIVATE :
@@ -1377,6 +1417,10 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
     createGeographicGeocentric(const crs::CRSNNPtr &sourceCRS,
                                const crs::CRSNNPtr &targetCRS);
 
+    PROJ_INTERNAL static ConversionNNPtr
+    createGeographicGeocentricLatitude(const crs::CRSNNPtr &sourceCRS,
+                                       const crs::CRSNNPtr &targetCRS);
+
     //! @endcond
 
   protected:
@@ -1406,12 +1450,6 @@ class PROJ_GCC_DLL Conversion : public SingleOperation {
 
 // ---------------------------------------------------------------------------
 
-class Transformation;
-/** Shared pointer of Transformation */
-using TransformationPtr = std::shared_ptr<Transformation>;
-/** Non-null shared pointer of Transformation */
-using TransformationNNPtr = util::nn<TransformationPtr>;
-
 /** \brief A mathematical operation on coordinates in which parameters are
  * empirically derived from data containing the coordinates of a series of
  * points in both coordinate reference systems.
@@ -1565,9 +1603,6 @@ class PROJ_GCC_DLL Transformation : public SingleOperation {
         const crs::CRSNNPtr &targetCRSIn, const common::Length &offsetHeight,
         const std::vector<metadata::PositionalAccuracyNNPtr> &accuracies);
 
-    PROJ_DLL TransformationNNPtr substitutePROJAlternativeGridNames(
-        io::DatabaseContextNNPtr databaseContext) const;
-
     PROJ_DLL static TransformationNNPtr createChangeVerticalUnit(
         const util::PropertyMap &properties, const crs::CRSNNPtr &sourceCRSIn,
         const crs::CRSNNPtr &targetCRSIn, const common::Scale &factor,
@@ -1583,8 +1618,6 @@ class PROJ_GCC_DLL Transformation : public SingleOperation {
 
     PROJ_INTERNAL const std::string &getHeightToGeographic3DFilename() const;
 
-    PROJ_INTERNAL bool isLongitudeRotation() const;
-
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
@@ -1593,6 +1626,17 @@ class PROJ_GCC_DLL Transformation : public SingleOperation {
 
     PROJ_INTERNAL TransformationNNPtr shallowClone() const;
 
+    PROJ_INTERNAL TransformationNNPtr
+    promoteTo3D(const std::string &newName,
+                const io::DatabaseContextPtr &dbContext) const;
+
+    PROJ_INTERNAL TransformationNNPtr
+    demoteTo2D(const std::string &newName,
+               const io::DatabaseContextPtr &dbContext) const;
+
+    PROJ_INTERNAL static bool
+    isGeographic3DToGravityRelatedHeight(const OperationMethodNNPtr &method,
+                                         bool allowInverse);
     //! @endcond
 
   protected:
@@ -1609,6 +1653,7 @@ class PROJ_GCC_DLL Transformation : public SingleOperation {
         const override; // throw(FormattingException)
 
     PROJ_FRIEND(CoordinateOperationFactory);
+    PROJ_FRIEND(SingleOperation);
     PROJ_INTERNAL TransformationNNPtr inverseAsTransformation() const;
 
     PROJ_INTERNAL CoordinateOperationNNPtr _shallowClone() const override;
@@ -1820,9 +1865,9 @@ class PROJ_GCC_DLL CoordinateOperationContext {
         IGNORE_GRID_AVAILABILITY,
 
         /** Results will be presented as if grids known to PROJ (that is
-        * registered in the grid_alternatives table of its database) were
-        * available. Used typically when networking is enabled.
-        */
+         * registered in the grid_alternatives table of its database) were
+         * available. Used typically when networking is enabled.
+         */
         KNOWN_AVAILABLE,
     };
 
