@@ -1,7 +1,7 @@
 /******************************************************************************
  *
  * Project:  PROJ
- * Purpose:  ISO19111:2018 implementation
+ * Purpose:  ISO19111:2019 implementation
  * Author:   Even Rouault <even dot rouault at spatialys dot com>
  *
  ******************************************************************************
@@ -59,9 +59,10 @@ namespace datum {
  * subtype can be associated with only specific types of coordinate reference
  * systems.
  *
- * \remark Implements Datum from \ref ISO_19111_2018
+ * \remark Implements Datum from \ref ISO_19111_2019
  */
-class PROJ_GCC_DLL Datum : public common::ObjectUsage {
+class PROJ_GCC_DLL Datum : public common::ObjectUsage,
+                           public io::IJSONExportable {
   public:
     //! @cond Doxygen_Suppress
     PROJ_DLL ~Datum() override;
@@ -71,14 +72,17 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage {
     PROJ_DLL const util::optional<common::DateTime> &publicationDate() const;
     PROJ_DLL const common::IdentifiedObjectPtr &conventionalRS() const;
 
+    //! @cond Doxygen_Suppress
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
+    //! @endcond
+
   protected:
     PROJ_INTERNAL Datum();
 
-    PROJ_INTERNAL bool
-    __isEquivalentTo(const util::IComparable *other,
-                     util::IComparable::Criterion criterion =
-                         util::IComparable::Criterion::STRICT) const;
-
 #ifdef DOXYGEN_ENABLED
     std::string *anchorDefinition_;
     Date *publicationDate_;
@@ -88,6 +92,10 @@ class PROJ_GCC_DLL Datum : public common::ObjectUsage {
   protected:
     PROJ_INTERNAL void setAnchor(const util::optional<std::string> &anchor);
 
+    PROJ_INTERNAL void
+    setProperties(const util::PropertyMap
+                      &properties); // throw(InvalidValueTypeException)
+
   private:
     PROJ_OPAQUE_PRIVATE_DATA
     Datum &operator=(const Datum &other) = delete;
@@ -115,9 +123,10 @@ using DatumEnsembleNNPtr = util::nn<DatumEnsemblePtr>;
  * Every frame within the datum ensemble must be a realizations of the same
  * Terrestrial Reference System or Vertical Reference System.
  *
- * \remark Implements DatumEnsemble from \ref ISO_19111_2018
+ * \remark Implements DatumEnsemble from \ref ISO_19111_2019
  */
-class PROJ_GCC_DLL DatumEnsemble final : public common::IdentifiedObject {
+class PROJ_GCC_DLL DatumEnsemble final : public common::ObjectUsage,
+                                         public io::IJSONExportable {
   public:
     //! @cond Doxygen_Suppress
     PROJ_DLL ~DatumEnsemble() override;
@@ -135,7 +144,13 @@ class PROJ_GCC_DLL DatumEnsemble final : public common::IdentifiedObject {
     //! @cond Doxygen_Suppress
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
-                        //! @endcond
+
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(io::FormattingException)
+
+    PROJ_FOR_TEST DatumNNPtr
+    asDatum(const io::DatabaseContextPtr &dbContext) const;
+    //! @endcond
 
   protected:
 #ifdef DOXYGEN_ENABLED
@@ -168,10 +183,11 @@ using PrimeMeridianNNPtr = util::nn<PrimeMeridianPtr>;
  * \note The default value for prime meridian name is "Greenwich". When the
  * default applies, the value for the longitude shall be 0 (degrees).
  *
- * \remark Implements PrimeMeridian from \ref ISO_19111_2018
+ * \remark Implements PrimeMeridian from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL PrimeMeridian final : public common::IdentifiedObject,
-                                         public io::IPROJStringExportable {
+                                         public io::IPROJStringExportable,
+                                         public io::IJSONExportable {
   public:
     //! @cond Doxygen_Suppress
     PROJ_DLL ~PrimeMeridian() override;
@@ -198,10 +214,14 @@ class PROJ_GCC_DLL PrimeMeridian final : public common::IdentifiedObject,
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(io::FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
     PROJ_INTERNAL static std::string
     getPROJStringWellKnownName(const common::Angle &angle);
@@ -240,10 +260,11 @@ using EllipsoidNNPtr = util::nn<EllipsoidPtr>;
  * For the Earth an oblate biaxial ellipsoid is used: in mathematical terms,
  * it is a surface formed by the rotation of an ellipse about its minor axis.
  *
- * \remark Implements Ellipsoid from \ref ISO_19111_2018
+ * \remark Implements Ellipsoid from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL Ellipsoid final : public common::IdentifiedObject,
-                                     public io::IPROJStringExportable {
+                                     public io::IPROJStringExportable,
+                                     public io::IJSONExportable {
   public:
     //! @cond Doxygen_Suppress
     PROJ_DLL ~Ellipsoid() override;
@@ -300,10 +321,14 @@ class PROJ_GCC_DLL Ellipsoid final : public common::IdentifiedObject,
         _exportToWKT(io::WKTFormatter *formatter)
             const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(io::FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
     PROJ_INTERNAL void _exportToPROJString(io::PROJStringFormatter *formatter)
         const override; // throw(FormattingException)
@@ -369,7 +394,7 @@ using GeodeticReferenceFrameNNPtr = util::nn<GeodeticReferenceFramePtr>;
  *
  * \note In \ref ISO_19111_2007, this class was called GeodeticDatum.
  *
- * \remark Implements GeodeticReferenceFrame from \ref ISO_19111_2018
+ * \remark Implements GeodeticReferenceFrame from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
   public:
@@ -399,10 +424,18 @@ class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
+
+    PROJ_INTERNAL bool isEquivalentToNoExactTypeCheck(
+        const util::IComparable *other, util::IComparable::Criterion criterion,
+        const io::DatabaseContextPtr &dbContext) const;
     //! @endcond
 
   protected:
@@ -420,6 +453,10 @@ class PROJ_GCC_DLL GeodeticReferenceFrame : public Datum {
     PROJ_INTERNAL static const GeodeticReferenceFrameNNPtr createEPSG_6269();
     PROJ_INTERNAL static const GeodeticReferenceFrameNNPtr createEPSG_6326();
 
+    bool hasEquivalentNameToUsingAlias(
+        const IdentifiedObject *other,
+        const io::DatabaseContextPtr &dbContext) const override;
+
   private:
     PROJ_OPAQUE_PRIVATE_DATA
     GeodeticReferenceFrame(const GeodeticReferenceFrame &other) = delete;
@@ -443,7 +480,7 @@ using DynamicGeodeticReferenceFrameNNPtr =
  * For example defining station coordinates having linear velocities to account
  * for crustal motion.
  *
- * \remark Implements DynamicGeodeticReferenceFrame from \ref ISO_19111_2018
+ * \remark Implements DynamicGeodeticReferenceFrame from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL DynamicGeodeticReferenceFrame final
     : public GeodeticReferenceFrame {
@@ -464,10 +501,11 @@ class PROJ_GCC_DLL DynamicGeodeticReferenceFrame final
            const util::optional<std::string> &deformationModelNameIn);
 
     //! @cond Doxygen_Suppress
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
@@ -498,7 +536,7 @@ class PROJ_GCC_DLL DynamicGeodeticReferenceFrame final
 /** \brief The specification of the method by which the vertical reference frame
  * is realized.
  *
- * \remark Implements RealizationMethod from \ref ISO_19111_2018
+ * \remark Implements RealizationMethod from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL RealizationMethod : public util::CodeList {
   public:
@@ -510,7 +548,7 @@ class PROJ_GCC_DLL RealizationMethod : public util::CodeList {
     PROJ_FRIEND_OPTIONAL(RealizationMethod);
     PROJ_DLL explicit RealizationMethod(
         const std::string &nameIn = std::string());
-    PROJ_DLL RealizationMethod(const RealizationMethod &other);
+    PROJ_DLL RealizationMethod(const RealizationMethod &other) = default;
     PROJ_DLL RealizationMethod &operator=(const RealizationMethod &other);
 };
 
@@ -528,7 +566,7 @@ using VerticalReferenceFrameNNPtr = util::nn<VerticalReferenceFramePtr>;
  *
  * \note In \ref ISO_19111_2007, this class was called VerticalDatum.
 
- * \remark Implements VerticalReferenceFrame from \ref ISO_19111_2018
+ * \remark Implements VerticalReferenceFrame from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL VerticalReferenceFrame : public Datum {
   public:
@@ -547,14 +585,25 @@ class PROJ_GCC_DLL VerticalReferenceFrame : public Datum {
                util::optional<RealizationMethod>());
 
     //! @cond Doxygen_Suppress
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
+
+    PROJ_INTERNAL bool isEquivalentToNoExactTypeCheck(
+        const util::IComparable *other, util::IComparable::Criterion criterion,
+        const io::DatabaseContextPtr &dbContext) const;
 
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
-                        //! @endcond
+
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL const std::string &getWKT1DatumType() const;
+
+    //! @endcond
 
   protected:
 #ifdef DOXYGEN_ENABLED
@@ -585,7 +634,7 @@ using DynamicVerticalReferenceFrameNNPtr =
  * For example defining station heights have velocity to account for
  * post-glacial isostatic rebound motion.
  *
- * \remark Implements DynamicVerticalReferenceFrame from \ref ISO_19111_2018
+ * \remark Implements DynamicVerticalReferenceFrame from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL DynamicVerticalReferenceFrame final
     : public VerticalReferenceFrame {
@@ -606,10 +655,11 @@ class PROJ_GCC_DLL DynamicVerticalReferenceFrame final
            const util::optional<std::string> &deformationModelNameIn);
 
     //! @cond Doxygen_Suppress
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
@@ -645,7 +695,7 @@ using TemporalDatumNNPtr = util::nn<TemporalDatumPtr>;
 /** \brief The definition of the relationship of a temporal coordinate system
  * to an object. The object is normally time on the Earth.
  *
- * \remark Implements TemporalDatum from \ref ISO_19111_2018
+ * \remark Implements TemporalDatum from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL TemporalDatum final : public Datum {
   public:
@@ -668,10 +718,14 @@ class PROJ_GCC_DLL TemporalDatum final : public Datum {
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
     //! @endcond
 
   protected:
@@ -698,7 +752,7 @@ using EngineeringDatumNNPtr = util::nn<EngineeringDatumPtr>;
  * point at a construction site), or be a defined point on a moving vehicle
  * (such as on a ship or satellite), or a defined point of an image.
  *
- * \remark Implements EngineeringDatum from \ref ISO_19111_2018
+ * \remark Implements EngineeringDatum from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL EngineeringDatum final : public Datum {
   public:
@@ -716,10 +770,14 @@ class PROJ_GCC_DLL EngineeringDatum final : public Datum {
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
     //! @endcond
 
   protected:
@@ -742,7 +800,7 @@ using ParametricDatumNNPtr = util::nn<ParametricDatumPtr>;
  * particular reference surface used as the origin of a parametric coordinate
  * system, including its position with respect to the Earth.
  *
- * \remark Implements ParametricDatum from \ref ISO_19111_2018
+ * \remark Implements ParametricDatum from \ref ISO_19111_2019
  */
 class PROJ_GCC_DLL ParametricDatum final : public Datum {
   public:
@@ -760,10 +818,14 @@ class PROJ_GCC_DLL ParametricDatum final : public Datum {
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
+
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
     //! @endcond
 
   protected:
