@@ -69,6 +69,7 @@ class WKTConstants {
     static const std::string EXTENSION;   // WKT1 only - GDAL specific
     static const std::string LOCAL_CS;    // WKT1 only
     static const std::string LOCAL_DATUM; // WKT1 only
+    static const std::string LINUNIT;     // WKT1 ESRI (ArcGIS Pro >= 2.7)
 
     // WKT2 preferred
     static const std::string GEODCRS;
@@ -173,7 +174,6 @@ struct projCppContext {
     PJ_CONTEXT *ctx_ = nullptr;
     std::string dbPath_{};
     std::vector<std::string> auxDbPaths_{};
-    bool autoCloseDb_ = false;
 
     projCppContext(const projCppContext &) = delete;
     projCppContext &operator=(const projCppContext &) = delete;
@@ -201,15 +201,9 @@ struct projCppContext {
         return auxDbPaths_;
     }
 
-    void setAutoCloseDb(bool autoClose) { autoCloseDb_ = autoClose; }
-    inline bool getAutoCloseDb() const { return autoCloseDb_; }
-
-    // cppcheck-suppress functionStatic
-    void closeDb();
-
-    void autoCloseDbIfNeeded();
-
     NS_PROJ::io::DatabaseContextNNPtr getDatabaseContext();
+
+    void closeDb() { databaseContext_ = nullptr; }
 };
 
 //! @endcond
