@@ -178,7 +178,7 @@ typedef struct {
     char crs_dst[MAX_OPERATION+1];
     char crs_src[MAX_OPERATION+1];
     PJ *P;
-    PJ_COORD a, b, c, e;
+    PJ_COORD a, b, e;
     PJ_DIRECTION dir;
     int verbosity;
     int skip;
@@ -1113,8 +1113,7 @@ static int dispatch (const char *cmnd, const char *args) {
 
 
 namespace { // anonymous namespace
-struct errno_vs_err_const {const char *the_err_const; int the_errno;};
-static const struct errno_vs_err_const lookup[] = {
+static const struct {const char *the_err_const; int the_errno;} lookup[] = {
 
     { "invalid_op",                              PROJ_ERR_INVALID_OP },
     { "invalid_op_wrong_syntax",                 PROJ_ERR_INVALID_OP_WRONG_SYNTAX },
