@@ -98,7 +98,7 @@ PROJ_HEAD(cart,    "Geodetic/cartesian conversions");
     (WP2, below)
 
     These routines are probably not as robust at those in
-    geocent.c, at least thay haven't been through as heavy
+    geocent.c, at least they haven't been through as heavy
     use as their geocent sisters. Some care has been taken
     to avoid singularities, but extreme cases (e.g. setting
     es, the squared eccentricity, to 1), will cause havoc.
@@ -212,7 +212,8 @@ static PJ_XY cart_forward (PJ_LP lp, PJ *P) {
     point.lp = lp;
     point.lpz.z = 0;
 
-    point.xyz = cartesian (point.lpz, P);
+    const auto xyz = cartesian (point.lpz, P);
+    point.xyz = xyz;
     return point.xy;
 }
 
@@ -222,7 +223,8 @@ static PJ_LP cart_reverse (PJ_XY xy, PJ *P) {
     point.xy = xy;
     point.xyz.z = 0;
 
-    point.lpz = geodetic (point.xyz, P);
+    const auto lpz = geodetic (point.xyz, P);
+    point.lpz = lpz;
     return point.lp;
 }
 
