@@ -91,13 +91,16 @@ pj_ctx pj_ctx::createDefault()
     ctx.logger = pj_stderr_logger;
     NS_PROJ::FileManager::fillDefaultNetworkInterface(&ctx);
 
-    if( getenv("PROJ_DEBUG") != nullptr )
+    const char* projDebug = getenv("PROJ_DEBUG");
+    if( projDebug != nullptr )
     {
-        if( atoi(getenv("PROJ_DEBUG")) >= -PJ_LOG_TRACE )
-            ctx.debug_level = atoi(getenv("PROJ_DEBUG"));
+        const int debugLevel = atoi(projDebug);
+        if( debugLevel >= -PJ_LOG_TRACE )
+            ctx.debug_level = debugLevel;
         else
             ctx.debug_level = PJ_LOG_TRACE;
     }
+
     return ctx;
 }
 
@@ -113,17 +116,6 @@ projCppContext* pj_ctx::get_cpp_context()
     return cpp_context;
 }
 
-/**************************************************************************/
-/*                           safeAutoCloseDbIfNeeded()                      */
-/**************************************************************************/
-
-void pj_ctx::safeAutoCloseDbIfNeeded()
-{
-    if (cpp_context) {
-        cpp_context->autoCloseDbIfNeeded();
-    }
-}
-
 /************************************************************************/
 /*                           set_search_paths()                         */
 /************************************************************************/
@@ -151,29 +143,35 @@ void pj_ctx::set_ca_bundle_path(const std::string& ca_bundle_path_in)
 }
 
 /************************************************************************/
-/*                  pj_ctx(const pj_ctx& other)                   */
+/*                  pj_ctx(const pj_ctx& other)                         */
 /************************************************************************/
 
 pj_ctx::pj_ctx(const pj_ctx& other) :
+    lastFullErrorMessage(std::string()),
+    last_errno(0),
     debug_level(other.debug_level),
     logger(other.logger),
     logger_app_data(other.logger_app_data),
     cpp_context(other.cpp_context ? other.cpp_context->clone(this) : nullptr),
     use_proj4_init_rules(other.use_proj4_init_rules),
+    forceOver(other.forceOver),
     epsg_file_exists(other.epsg_file_exists),
-    ca_bundle_path(other.ca_bundle_path),
-    env_var_proj_lib(other.env_var_proj_lib),
+    env_var_proj_data(other.env_var_proj_data),
     file_finder(other.file_finder),
     file_finder_user_data(other.file_finder_user_data),
+    defer_grid_opening(false),
     custom_sqlite3_vfs_name(other.custom_sqlite3_vfs_name),
     user_writable_directory(other.user_writable_directory),
     // BEGIN ini file settings
     iniFileLoaded(other.iniFileLoaded),
     endpoint(other.endpoint),
     networking(other.networking),
+    ca_bundle_path(other.ca_bundle_path),
     gridChunkCache(other.gridChunkCache),
-    defaultTmercAlgo(other.defaultTmercAlgo)
+    defaultTmercAlgo(other.defaultTmercAlgo),
     // END ini file settings
+    projStringParserCreateFromPROJStringRecursionCounter(0),
+    pipelineInitRecursiongCounter(0)
 {
     set_search_paths(other.search_paths);
 }
