@@ -30,6 +30,11 @@
 #endif
 #define LRU11_DO_NOT_DEFINE_OUT_OF_CLASS_METHODS
 
+#if !defined(_WIN32) && !defined(_GNU_SOURCE)
+// For usleep() on Cygwin
+#define _GNU_SOURCE
+#endif
+
 #include <stdlib.h>
 
 #include <algorithm>
@@ -40,25 +45,10 @@
 #include "proj.h"
 #include "proj/internal/internal.hpp"
 #include "proj/internal/lru_cache.hpp"
+#include "proj/internal/mutex.hpp"
 #include "proj_internal.h"
 #include "sqlite3_utils.hpp"
 
-#ifdef __MINGW32__
-// mingw32-win32 doesn't implement std::mutex
-namespace {
-class MyMutex {
-  public:
-    // cppcheck-suppress functionStatic
-    void lock() { pj_acquire_lock(); }
-    // cppcheck-suppress functionStatic
-    void unlock() { pj_release_lock(); }
-};
-} // namespace
-#else
-#include <mutex>
-#define MyMutex std::mutex
-#endif
-
 #ifdef CURL_ENABLED
 #include <curl/curl.h>
 #include <sqlite3.h> // for sqlite3_snprintf
@@ -152,7 +142,7 @@ class NetworkChunkCache {
     };
 
     lru11::Cache<
-        Key, std::shared_ptr<std::vector<unsigned char>>, MyMutex,
+        Key, std::shared_ptr<std::vector<unsigned char>>, NS_PROJ::mutex,
         std::unordered_map<
             Key,
             typename std::list<lru11::KeyValuePair<
@@ -176,7 +166,7 @@ class NetworkFilePropertiesCache {
     void clearMemoryCache();
 
   private:
-    lru11::Cache<std::string, FileProperties, MyMutex> cache_{};
+    lru11::Cache<std::string, FileProperties, NS_PROJ::mutex> cache_{};
 };
 
 // ---------------------------------------------------------------------------
@@ -1200,7 +1190,7 @@ bool NetworkFilePropertiesCache::tryGet(PJ_CONTEXT *ctx, const std::string &url,
     if (stmt->execute() != SQLITE_ROW) {
         return false;
     }
-    props.lastChecked = stmt->getInt64();
+    props.lastChecked = static_cast<time_t>(stmt->getInt64());
     props.size = stmt->getInt64();
     const char *lastModified = stmt->getText();
     props.lastModified = lastModified ? lastModified : std::string();
@@ -1523,8 +1513,7 @@ struct CurlFileHandle {
     CurlFileHandle(const CurlFileHandle &) = delete;
     CurlFileHandle &operator=(const CurlFileHandle &) = delete;
 
-    explicit CurlFileHandle(const char *url, CURL *handle,
-                            const char *ca_bundle_path);
+    explicit CurlFileHandle(PJ_CONTEXT *ctx, const char *url, CURL *handle);
     ~CurlFileHandle();
 
     static PROJ_NETWORK_HANDLE *
@@ -1596,46 +1585,53 @@ static std::string GetExecutableName() {
 
 // ---------------------------------------------------------------------------
 
-CurlFileHandle::CurlFileHandle(const char *url, CURL *handle,
-                               const char *ca_bundle_path)
+static void checkRet(PJ_CONTEXT *ctx, CURLcode code, int line) {
+    if (code != CURLE_OK) {
+        pj_log(ctx, PJ_LOG_ERROR, "curl_easy_setopt at line %d failed", line);
+    }
+}
+
+#define CHECK_RET(ctx, code) checkRet(ctx, code, __LINE__)
+
+// ---------------------------------------------------------------------------
+
+static std::string pj_context_get_bundle_path(PJ_CONTEXT *ctx) {
+    pj_load_ini(ctx);
+    return ctx->ca_bundle_path;
+}
+
+// ---------------------------------------------------------------------------
+
+CurlFileHandle::CurlFileHandle(PJ_CONTEXT *ctx, const char *url, CURL *handle)
     : m_url(url), m_handle(handle) {
-    curl_easy_setopt(handle, CURLOPT_URL, m_url.c_str());
+    CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_URL, m_url.c_str()));
 
     if (getenv("PROJ_CURL_VERBOSE"))
-        curl_easy_setopt(handle, CURLOPT_VERBOSE, 1);
+        CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_VERBOSE, 1));
 
 // CURLOPT_SUPPRESS_CONNECT_HEADERS is defined in curl 7.54.0 or newer.
 #if LIBCURL_VERSION_NUM >= 0x073600
-    curl_easy_setopt(handle, CURLOPT_SUPPRESS_CONNECT_HEADERS, 1L);
+    CHECK_RET(ctx,
+              curl_easy_setopt(handle, CURLOPT_SUPPRESS_CONNECT_HEADERS, 1L));
 #endif
 
     // Enable following redirections.  Requires libcurl 7.10.1 at least.
-    curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1);
-    curl_easy_setopt(handle, CURLOPT_MAXREDIRS, 10);
+    CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1));
+    CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_MAXREDIRS, 10));
 
     if (getenv("PROJ_UNSAFE_SSL")) {
-        curl_easy_setopt(handle, CURLOPT_SSL_VERIFYPEER, 0L);
-        curl_easy_setopt(handle, CURLOPT_SSL_VERIFYHOST, 0L);
+        CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_SSL_VERIFYPEER, 0L));
+        CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_SSL_VERIFYHOST, 0L));
     }
 
-    // Custom path to SSL certificates.
-    if (ca_bundle_path == nullptr) {
-        ca_bundle_path = getenv("PROJ_CURL_CA_BUNDLE");
-    }
-    if (ca_bundle_path == nullptr) {
-        // Name of environment variable used by the curl binary
-        ca_bundle_path = getenv("CURL_CA_BUNDLE");
-    }
-    if (ca_bundle_path == nullptr) {
-        // Name of environment variable used by the curl binary (tested
-        // after CURL_CA_BUNDLE
-        ca_bundle_path = getenv("SSL_CERT_FILE");
-    }
-    if (ca_bundle_path != nullptr) {
-        curl_easy_setopt(handle, CURLOPT_CAINFO, ca_bundle_path);
+    const auto ca_bundle_path = pj_context_get_bundle_path(ctx);
+    if (!ca_bundle_path.empty()) {
+        CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_CAINFO,
+                                        ca_bundle_path.c_str()));
     }
 
-    curl_easy_setopt(handle, CURLOPT_ERRORBUFFER, m_szCurlErrBuf);
+    CHECK_RET(ctx,
+              curl_easy_setopt(handle, CURLOPT_ERRORBUFFER, m_szCurlErrBuf));
 
     if (getenv("PROJ_NO_USERAGENT") == nullptr) {
         m_useragent = "PROJ " STR(PROJ_VERSION_MAJOR) "." STR(
@@ -1644,7 +1640,8 @@ CurlFileHandle::CurlFileHandle(const char *url, CURL *handle,
         if (!exeName.empty()) {
             m_useragent = exeName + " using " + m_useragent;
         }
-        curl_easy_setopt(handle, CURLOPT_USERAGENT, m_useragent.data());
+        CHECK_RET(ctx, curl_easy_setopt(handle, CURLOPT_USERAGENT,
+                                        m_useragent.data()));
     }
 }
 
@@ -1702,9 +1699,8 @@ PROJ_NETWORK_HANDLE *CurlFileHandle::open(PJ_CONTEXT *ctx, const char *url,
     if (!hCurlHandle)
         return nullptr;
 
-    auto file = std::unique_ptr<CurlFileHandle>(new CurlFileHandle(
-        url, hCurlHandle,
-        ctx->ca_bundle_path.empty() ? nullptr : ctx->ca_bundle_path.c_str()));
+    auto file = std::unique_ptr<CurlFileHandle>(
+        new CurlFileHandle(ctx, url, hCurlHandle));
 
     double oldDelay = MIN_RETRY_DELAY_MS;
     std::string headers;
@@ -1715,19 +1711,20 @@ PROJ_NETWORK_HANDLE *CurlFileHandle::open(PJ_CONTEXT *ctx, const char *url,
                      offset + size_to_read - 1);
 
     while (true) {
-        curl_easy_setopt(hCurlHandle, CURLOPT_RANGE, szBuffer);
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_RANGE, szBuffer));
 
         headers.clear();
         headers.reserve(16 * 1024);
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, &headers);
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION,
-                         pj_curl_write_func);
+        CHECK_RET(ctx,
+                  curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, &headers));
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION,
+                                        pj_curl_write_func));
 
         body.clear();
         body.reserve(size_to_read);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, &body);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION,
-                         pj_curl_write_func);
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, &body));
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION,
+                                        pj_curl_write_func));
 
         file->m_szCurlErrBuf[0] = '\0';
 
@@ -1736,11 +1733,15 @@ PROJ_NETWORK_HANDLE *CurlFileHandle::open(PJ_CONTEXT *ctx, const char *url,
         long response_code = 0;
         curl_easy_getinfo(hCurlHandle, CURLINFO_HTTP_CODE, &response_code);
 
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, nullptr);
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION, nullptr);
+        CHECK_RET(ctx,
+                  curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, nullptr));
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION,
+                                        nullptr));
 
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, nullptr);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION, nullptr);
+        CHECK_RET(ctx,
+                  curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, nullptr));
+        CHECK_RET(
+            ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION, nullptr));
 
         if (response_code == 0 || response_code >= 300) {
             const double delay =
@@ -1809,19 +1810,20 @@ static size_t pj_curl_read_range(PJ_CONTEXT *ctx,
                      offset + size_to_read - 1);
 
     while (true) {
-        curl_easy_setopt(hCurlHandle, CURLOPT_RANGE, szBuffer);
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_RANGE, szBuffer));
 
         headers.clear();
         headers.reserve(16 * 1024);
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, &headers);
-        curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION,
-                         pj_curl_write_func);
+        CHECK_RET(ctx,
+                  curl_easy_setopt(hCurlHandle, CURLOPT_HEADERDATA, &headers));
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_HEADERFUNCTION,
+                                        pj_curl_write_func));
 
         body.clear();
         body.reserve(size_to_read);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, &body);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION,
-                         pj_curl_write_func);
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, &body));
+        CHECK_RET(ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION,
+                                        pj_curl_write_func));
 
         handle->m_szCurlErrBuf[0] = '\0';
 
@@ -1830,8 +1832,10 @@ static size_t pj_curl_read_range(PJ_CONTEXT *ctx,
         long response_code = 0;
         curl_easy_getinfo(hCurlHandle, CURLINFO_HTTP_CODE, &response_code);
 
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, nullptr);
-        curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION, nullptr);
+        CHECK_RET(ctx,
+                  curl_easy_setopt(hCurlHandle, CURLOPT_WRITEDATA, nullptr));
+        CHECK_RET(
+            ctx, curl_easy_setopt(hCurlHandle, CURLOPT_WRITEFUNCTION, nullptr));
 
         if (response_code == 0 || response_code >= 300) {
             const double delay =
@@ -2034,7 +2038,6 @@ int proj_context_set_enable_network(PJ_CONTEXT *ctx, int enable) {
     }
     // Load ini file, now so as to override its network settings
     pj_load_ini(ctx);
-    ctx->networking.enabled_env_variable_checked = true;
     ctx->networking.enabled = enable != FALSE;
 #ifdef CURL_ENABLED
     return ctx->networking.enabled;
@@ -2056,22 +2059,10 @@ int proj_context_is_network_enabled(PJ_CONTEXT *ctx) {
     if (ctx == nullptr) {
         ctx = pj_get_default_ctx();
     }
-    if (ctx->networking.enabled_env_variable_checked) {
-        return ctx->networking.enabled;
-    }
-    const char *enabled = getenv("PROJ_NETWORK");
-    if (enabled && enabled[0] != '\0') {
-        ctx->networking.enabled = ci_equal(enabled, "ON") ||
-                                  ci_equal(enabled, "YES") ||
-                                  ci_equal(enabled, "TRUE");
-    }
     pj_load_ini(ctx);
-    ctx->networking.enabled_env_variable_checked = true;
     return ctx->networking.enabled;
 }
 
-//! @endcond
-
 // ---------------------------------------------------------------------------
 
 /** Define the URL endpoint to query for remote grids.
@@ -2213,7 +2204,7 @@ void proj_grid_cache_clear(PJ_CONTEXT *ctx) {
  *                           the delay between the last time it has been
  *                           verified and the current time exceeds the TTL
  *                           setting. This can save network accesses.
- *                           If set to TRUE, PROJ will unconditionnally
+ *                           If set to TRUE, PROJ will unconditionally
  *                           check from the server the recentness of the file.
  * @return TRUE if the file must be downloaded with proj_download_file()
  * @since 7.0
@@ -2258,7 +2249,7 @@ int proj_is_download_needed(PJ_CONTEXT *ctx, const char *url_or_filename,
     }
 
     NS_PROJ::FileProperties cachedProps;
-    cachedProps.lastChecked = stmt->getInt64();
+    cachedProps.lastChecked = static_cast<time_t>(stmt->getInt64());
     cachedProps.size = stmt->getInt64();
     const char *lastModified = stmt->getText();
     cachedProps.lastModified = lastModified ? lastModified : std::string();
@@ -2342,7 +2333,7 @@ int proj_is_download_needed(PJ_CONTEXT *ctx, const char *url_or_filename,
  *                           the delay between the last time it has been
  *                           verified and the current time exceeds the TTL
  *                           setting. This can save network accesses.
- *                           If set to TRUE, PROJ will unconditionnally
+ *                           If set to TRUE, PROJ will unconditionally
  *                           check from the server the recentness of the file.
  * @param progress_cbk Progress callback, or NULL.
  *                     The passed percentage is in the [0, 1] range.
