@@ -71,6 +71,8 @@ PROJ_HEAD(hgridshift, "Horizontal grid shift")
 PROJ_HEAD(horner,    "Horner polynomial evaluation")
 PROJ_HEAD(igh,  "Interrupted Goode Homolosine")
 PROJ_HEAD(igh_o,  "Interrupted Goode Homolosine Oceanic View")
+PROJ_HEAD(imoll, "Interrupted Mollweide")
+PROJ_HEAD(imoll_o, "Interrupted Mollweide Oceanic View")
 PROJ_HEAD(imw_p, "International Map of the World Polyconic")
 PROJ_HEAD(isea, "Icosahedral Snyder Equal Area")
 PROJ_HEAD(kav5, "Kavrayskiy V")
@@ -168,6 +170,7 @@ PROJ_HEAD(vandg, "van der Grinten (I)")
 PROJ_HEAD(vandg2, "van der Grinten II")
 PROJ_HEAD(vandg3, "van der Grinten III")
 PROJ_HEAD(vandg4, "van der Grinten IV")
+PROJ_HEAD(vertoffset, "Vertical Offset and Slope")
 PROJ_HEAD(vitk1, "Vitkovsky I")
 PROJ_HEAD(vgridshift, "Vertical grid shift")
 PROJ_HEAD(wag1, "Wagner I (Kavrayskiy VI)")
