@@ -5,7 +5,7 @@
 
 #include "proj.h"
 #include "proj_internal.h"
-#include "proj_math.h"
+#include <math.h>
 
 namespace { // anonymous namespace
 struct pj_opaque {
@@ -31,8 +31,9 @@ static PJ_XY eqdc_e_forward (PJ_LP lp, PJ *P) {          /* Ellipsoidal, forward
 
     Q->rho = Q->c - (Q->ellips ? pj_mlfn(lp.phi, sin(lp.phi),
         cos(lp.phi), Q->en) : lp.phi);
-    xy.x = Q->rho * sin( lp.lam *= Q->n );
-    xy.y = Q->rho0 - Q->rho * cos(lp.lam);
+    const double lam_mul_n = lp.lam * Q->n;
+    xy.x = Q->rho * sin(lam_mul_n);
+    xy.y = Q->rho0 - Q->rho * cos(lam_mul_n);
 
     return xy;
 }
@@ -67,7 +68,7 @@ static PJ *destructor (PJ *P, int errlev) {                        /* Destructor
     if (nullptr==P->opaque)
         return pj_default_destructor (P, errlev);
 
-    pj_dealloc (static_cast<struct pj_opaque*>(P->opaque)->en);
+    free (static_cast<struct pj_opaque*>(P->opaque)->en);
     return pj_default_destructor (P, errlev);
 }
 
@@ -76,27 +77,41 @@ PJ *PROJECTION(eqdc) {
     double cosphi, sinphi;
     int secant;
 
-    struct pj_opaque *Q = static_cast<struct pj_opaque*>(pj_calloc (1, sizeof (struct pj_opaque)));
+    struct pj_opaque *Q = static_cast<struct pj_opaque*>(calloc (1, sizeof (struct pj_opaque)));
     if (nullptr==Q)
-        return pj_default_destructor (P, ENOMEM);
+        return pj_default_destructor (P, PROJ_ERR_OTHER /*ENOMEM*/);
     P->opaque = Q;
     P->destructor = destructor;
 
     Q->phi1 = pj_param(P->ctx, P->params, "rlat_1").f;
     Q->phi2 = pj_param(P->ctx, P->params, "rlat_2").f;
-    if (fabs(Q->phi1) > M_HALFPI || fabs(Q->phi2) > M_HALFPI)
-        return destructor(P, PJD_ERR_LAT_LARGER_THAN_90);
 
+    if (fabs(Q->phi1) > M_HALFPI)
+    {
+        proj_log_error(P, _("Invalid value for lat_1: |lat_1| should be <= 90°"));
+        return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+    }
+
+    if (fabs(Q->phi2) > M_HALFPI)
+    {
+        proj_log_error(P, _("Invalid value for lat_2: |lat_2| should be <= 90°"));
+        return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+    }
     if (fabs(Q->phi1 + Q->phi2) < EPS10)
-        return destructor (P, PJD_ERR_CONIC_LAT_EQUAL);
+    {
+        proj_log_error(P, _("Invalid value for lat_1 and lat_2: |lat_1 + lat_2| should be > 0"));
+        return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+    }
 
     if (!(Q->en = pj_enfn(P->es)))
-        return destructor(P, ENOMEM);
+        return destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
 
-    Q->n = sinphi = sin(Q->phi1);
+    sinphi = sin(Q->phi1);
+    Q->n = sinphi;
     cosphi = cos(Q->phi1);
     secant = fabs(Q->phi1 - Q->phi2) >= EPS10;
-    if( (Q->ellips = (P->es > 0.)) ) {
+    Q->ellips = (P->es > 0.);
+    if( Q->ellips ) {
         double ml1, m1;
 
         m1 = pj_msfn(sinphi, cosphi, P->es);
@@ -104,11 +119,16 @@ PJ *PROJECTION(eqdc) {
         if (secant) { /* secant cone */
             sinphi = sin(Q->phi2);
             cosphi = cos(Q->phi2);
-            Q->n = (m1 - pj_msfn(sinphi, cosphi, P->es)) /
-                (pj_mlfn(Q->phi2, sinphi, cosphi, Q->en) - ml1);
+            const double ml2 = pj_mlfn(Q->phi2, sinphi, cosphi, Q->en);
+            if (ml1 == ml2) {
+                proj_log_error(P, _("Eccentricity too close to 1"));
+                return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+            }
+            Q->n = (m1 - pj_msfn(sinphi, cosphi, P->es)) / (ml2 - ml1);
             if (Q->n == 0) {
                 // Not quite, but es is very close to 1...
-                return destructor(P, PJD_ERR_INVALID_ECCENTRICITY);
+                proj_log_error(P, _("Invalid value for eccentricity"));
+                return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
             }
         }
         Q->c = ml1 + m1 / Q->n;
@@ -117,6 +137,11 @@ PJ *PROJECTION(eqdc) {
     } else {
         if (secant)
             Q->n = (cosphi - cos(Q->phi2)) / (Q->phi2 - Q->phi1);
+        if (Q->n == 0)
+        {
+            proj_log_error(P, _("Invalid value for lat_1 and lat_2: lat_1 + lat_2 should be > 0"));
+            return destructor(P, PROJ_ERR_INVALID_OP_ILLEGAL_ARG_VALUE);
+        }
         Q->c = Q->phi1 + cos(Q->phi1) / Q->n;
         Q->rho0 = Q->c - P->phi0;
     }
