@@ -179,4 +179,14 @@ TEST(proj_context, read_grid_from_user_writable_directory) {
     MyUnlink(filename);
 }
 
+// ---------------------------------------------------------------------------
+
+TEST(proj_context, proj_context_set_ca_bundle_path) {
+    std::string dirname("/tmp/dummmy/path/cacert.pem");
+    auto ctx = proj_context_create();
+    proj_context_set_ca_bundle_path(ctx, dirname.c_str());
+    ASSERT_EQ(ctx->ca_bundle_path, dirname);
+    proj_context_destroy(ctx);
+}
+
 } // namespace
